from dataclasses import dataclass
from pathlib import Path

from karaokatalog.instructions.Instruction import Instruction


@dataclass(frozen=True)
class MoveInstruction(Instruction):
    """
    Move the old path (might point to a file, a folder or a link) to the new path, no questions asked.
    Does not override existing paths.
    """

    old_path: Path
    new_path: Path

    def __call__(self) -> None:
        if self.new_path.exists():
            raise FileExistsError("New path already exists, not moving anything")

        self.new_path.parent.mkdir(exist_ok=True, parents=True)
        self.old_path.rename(self.new_path)
